@@ -223,7 +223,7 @@ UPDATE_ALLOWED_STATES = (DEPLOYFAIL, INSPECTING, INSPECTFAIL, INSPECTWAIT,
                          UNRESCUEFAIL)
 """Transitional states in which we allow updating a node."""
 
-DELETE_ALLOWED_STATES = (AVAILABLE, MANAGEABLE, ENROLL, ADOPTFAIL)
+DELETE_ALLOWED_STATES = (MANAGEABLE, ENROLL, ADOPTFAIL)
 """States in which node deletion is allowed."""
 
 STABLE_STATES = (ENROLL, MANAGEABLE, AVAILABLE, ACTIVE, ERROR, RESCUE)
@@ -234,6 +234,29 @@ UNSTABLE_STATES = (DEPLOYING, DEPLOYWAIT, CLEANING, CLEANWAIT, VERIFYING,
                    RESCUEWAIT, UNRESCUING)
 """States that can be changed without external request."""
 
+STUCK_STATES_TREATED_AS_FAIL = (DEPLOYING, CLEANING, VERIFYING, INSPECTING,
+                                ADOPTING, RESCUING, UNRESCUING)
+"""States that cannot be resumed once a conductor dies.
+
+If a node gets stuck with one of these states for some reason
+(eg. conductor goes down when executing task), node will be moved
+to fail state.
+"""
+
+_LOOKUP_ALLOWED_STATES = (DEPLOYING, DEPLOYWAIT, CLEANING, CLEANWAIT,
+                          INSPECTING, RESCUING, RESCUEWAIT)
+LOOKUP_ALLOWED_STATES = frozenset(_LOOKUP_ALLOWED_STATES)
+
+"""States when API lookups are normally allowed for nodes."""
+
+_FASTTRACK_LOOKUP_ALLOWED_STATES = (ENROLL, MANAGEABLE, AVAILABLE,
+                                    DEPLOYING, DEPLOYWAIT, CLEANING,
+                                    CLEANWAIT, INSPECTING, RESCUING,
+                                    RESCUEWAIT)
+FASTTRACK_LOOKUP_ALLOWED_STATES = frozenset(_FASTTRACK_LOOKUP_ALLOWED_STATES)
+"""States where API lookups are permitted with fast track enabled."""
+
+
 ##############
 # Power states
 ##############
@@ -253,6 +276,14 @@ SOFT_REBOOT = 'soft rebooting'
 SOFT_POWER_OFF = 'soft power off'
 """ Node is in the process of soft power off. """
 
+###################
+# Allocation states
+###################
+
+ALLOCATING = 'allocating'
+
+# States ERROR and ACTIVE are reused.
+
 
 #####################
 # State machine model
