@@ -19,7 +19,7 @@ from oslo_log import log as logging
 from oslo_utils import importutils
 
 from ironic.common import exception
-from ironic.common.i18n import _, _LE
+from ironic.common.i18n import _
 from ironic.drivers.modules.drac import common as drac_common
 
 drac_exceptions = importutils.try_import('dracclient.exceptions')
@@ -27,20 +27,26 @@ drac_exceptions = importutils.try_import('dracclient.exceptions')
 LOG = logging.getLogger(__name__)
 
 
-def validate_job_queue(node):
+def validate_job_queue(node, name_prefix=None):
     """Validates the job queue on the node.
 
     It raises an exception if an unfinished configuration job exists.
 
     :param node: an ironic node object.
+    :param name_prefix: A name prefix for jobs to validate.
     :raises: DracOperationError on an error from python-dracclient.
     """
 
     unfinished_jobs = list_unfinished_jobs(node)
-    if unfinished_jobs:
-        msg = _('Unfinished config jobs found: %(jobs)r. Make sure they are '
-                'completed before retrying.') % {'jobs': unfinished_jobs}
-        raise exception.DracOperationError(error=msg)
+    if name_prefix is not None:
+        # Filter out jobs that don't match the name prefix.
+        unfinished_jobs = [job for job in unfinished_jobs
+                           if job.name.startswith(name_prefix)]
+    if not unfinished_jobs:
+        return
+    msg = _('Unfinished config jobs found: %(jobs)r. Make sure they are '
+            'completed before retrying.') % {'jobs': unfinished_jobs}
+    raise exception.DracOperationError(error=msg)
 
 
 def get_job(node, job_id):
@@ -56,8 +62,8 @@ def get_job(node, job_id):
     try:
         return client.get_job(job_id)
     except drac_exceptions.BaseClientException as exc:
-        LOG.error(_LE('DRAC driver failed to get the job %(job_id)s '
-                      'for node %(node_uuid)s. Reason: %(error)s.'),
+        LOG.error('DRAC driver failed to get the job %(job_id)s '
+                  'for node %(node_uuid)s. Reason: %(error)s.',
                   {'node_uuid': node.uuid,
                    'error': exc})
         raise exception.DracOperationError(error=exc)
@@ -75,8 +81,8 @@ def list_unfinished_jobs(node):
     try:
         return client.list_jobs(only_unfinished=True)
     except drac_exceptions.BaseClientException as exc:
-        LOG.error(_LE('DRAC driver failed to get the list of unfinished jobs '
-                      'for node %(node_uuid)s. Reason: %(error)s.'),
+        LOG.error('DRAC driver failed to get the list of unfinished jobs '
+                  'for node %(node_uuid)s. Reason: %(error)s.',
                   {'node_uuid': node.uuid,
                    'error': exc})
         raise exception.DracOperationError(error=exc)
