@@ -614,7 +614,7 @@ def _calculate_volume_props(logical_disk, physical_disks, free_space_mb):
         error_msg = _('invalid number of physical disks was provided')
         raise exception.DracOperationError(error=error_msg)
 
-    disks_per_span = len(selected_disks) / spans_count
+    disks_per_span = int(len(selected_disks) / spans_count)
 
     # Best practice is to not pass span_length and span_depth when creating a
     # RAID10.  The iDRAC will dynamically calculate these values using maximum
@@ -1050,7 +1050,7 @@ class DracWSManRAID(base.RAIDInterface):
                 with task_manager.acquire(context, node_uuid,
                                           purpose=lock_purpose,
                                           shared=True) as task:
-                    if not isinstance(task.driver.raid, DracRAID):
+                    if not isinstance(task.driver.raid, DracWSManRAID):
                         continue
 
                     job_ids = driver_internal_info.get('raid_config_job_ids')
