@@ -21,6 +21,7 @@ import retrying
 from ironic.common import cinder
 from ironic.common import exception
 from ironic.common.i18n import _
+from ironic.common import pxe_utils
 from ironic.common import states
 from ironic.drivers import base
 from ironic.drivers import utils
@@ -76,15 +77,15 @@ class CinderStorage(base.StorageInterface):
         iscsi_uuids_found = []
         wwpn_found = 0
         wwnn_found = 0
-        ipxe_enabled = CONF.pxe.ipxe_enabled
-
+        ipxe_enabled = pxe_utils.is_ipxe_enabled(task)
         for connector in task.volume_connectors:
             if (connector.type in VALID_ISCSI_TYPES
                     and connector.connector_id is not None):
                 iscsi_uuids_found.append(connector.uuid)
                 if not ipxe_enabled:
                     msg = _("The [pxe]/ipxe_enabled option must "
-                            "be set to True to support network "
+                            "be set to True or the boot interface "
+                            "must be set to ``ipxe`` to support network "
                             "booting to an iSCSI volume.")
                     self._fail_validation(task, msg)
 
