@@ -57,30 +57,6 @@ class SwiftTestCase(base.TestCase):
             os_options={'object_storage_url': 'http://example.com/objects'}
         )
 
-    def test___init___radosgw(self, connection_mock, swift_session_mock):
-        """Check if client is properly initialized with radosgw"""
-
-        auth_url = 'http://1.2.3.4'
-        username = 'foo'
-        password = 'foo_password'
-        CONF.set_override('object_store_endpoint_type', 'radosgw',
-                          group='deploy')
-        opts = [cfg.StrOpt('auth_url'), cfg.StrOpt('username'),
-                cfg.StrOpt('password')]
-        CONF.register_opts(opts, group='swift')
-
-        CONF.set_override('auth_url', auth_url, group='swift')
-        CONF.set_override('username', username, group='swift')
-        CONF.set_override('password', password, group='swift')
-
-        swift.SwiftAPI()
-        params = {'authurl': auth_url,
-                  'user': username,
-                  'key': password,
-                  'retries': 2}
-        connection_mock.assert_called_once_with(**params)
-        self.assertFalse(swift_session_mock.called)
-
     @mock.patch.object(__builtin__, 'open', autospec=True)
     def test_create_object(self, open_mock, connection_mock, keystone_mock):
         swiftapi = swift.SwiftAPI()
